from PyObjCTools.TestSupport import TestCase
import XgridFoundation


class TestXGFileDownload(TestCase):
    def testMethods(self):
        self.assertArgIsBOOL(
            XgridFoundation.XGFileDownload.setDestination_allowOverwrite_, 1
        )



from PyObjCTools.TestSupport import TestCase
import XgridFoundation


class TestXGAuthenticator(TestCase):
    def testConstants(self):
        self.assertEqual(XgridFoundation.XGAuthenticatorStateUnauthenticated, 0)
        self.assertEqual(XgridFoundation.XGAuthenticatorStateAuthenticating, 1)
        self.assertEqual(XgridFoundation.XGAuthenticatorStateAuthenticated, 2)
        self.assertEqual(XgridFoundation.XGAuthenticatorStateFailed, 3)



from PyObjCTools.TestSupport import TestCase
import XgridFoundation


class TestXGController(TestCase):
    def testConstants(self):
        self.assertIsInstance(XgridFoundation.XGControllerWillDeallocNotification, str)



from PyObjCTools.TestSupport import TestCase
import XgridFoundation


class TestXGResource(TestCase):
    def testConstants(self):
        self.assertEqual(XgridFoundation.XGResourceStateUninitialized, 0)
        self.assertEqual(XgridFoundation.XGResourceStateOffline, 1)
        self.assertEqual(XgridFoundation.XGResourceStateConnecting, 2)
        self.assertEqual(XgridFoundation.XGResourceStateUnavailable, 3)
        self.assertEqual(XgridFoundation.XGResourceStateAvailable, 4)
        self.assertEqual(XgridFoundation.XGResourceStateWorking, 5)
        self.assertEqual(XgridFoundation.XGResourceStatePending, 6)
        self.assertEqual(XgridFoundation.XGResourceStateStarting, 7)
        self.assertEqual(XgridFoundation.XGResourceStateStagingIn, 8)
        self.assertEqual(XgridFoundation.XGResourceStateRunning, 9)
        self.assertEqual(XgridFoundation.XGResourceStateSuspended, 10)
        self.assertEqual(XgridFoundation.XGResourceStateStagingOut, 11)
        self.assertEqual(XgridFoundation.XGResourceStateCanceled, 12)
        self.assertEqual(XgridFoundation.XGResourceStateFailed, 13)
        self.assertEqual(XgridFoundation.XGResourceStateFinished, 14)

    def testMethods(self):
        self.assertResultIsBOOL(XgridFoundation.XGResource.isUpdating)
        self.assertResultIsBOOL(XgridFoundation.XGResource.isUpdated)



from PyObjCTools.TestSupport import TestCase, min_os_level
import XgridFoundation


class TestXGJob(TestCase):
    def testConstants(self):
        self.assertIsInstance(XgridFoundation.XGJobSpecificationNameKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationTypeKey, str)
        self.assertIsInstance(
            XgridFoundation.XGJobSpecificationSubmissionIdentifierKey, str
        )
        self.assertIsInstance(
            XgridFoundation.XGJobSpecificationSchedulerParametersKey, str
        )
        self.assertIsInstance(XgridFoundation.XGJobSpecificationGridIdentifierKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationDependsOnJobsKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationInputFilesKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationFileDataKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationIsExecutableKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationTaskPrototypesKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationInputFileMapKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationCommandKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationArgumentsKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationArgumentTypeKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationPathIdentifierKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationEnvironmentKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationInputStreamKey, str)
        self.assertIsInstance(
            XgridFoundation.XGJobSpecificationTaskSpecificationsKey, str
        )
        self.assertIsInstance(
            XgridFoundation.XGJobSpecificationTaskPrototypeIdentifierKey, str
        )
        self.assertIsInstance(XgridFoundation.XGJobSpecificationDependsOnTasksKey, str)
        self.assertIsInstance(
            XgridFoundation.XGJobSpecificationNotificationEmailKey, str
        )
        self.assertIsInstance(
            XgridFoundation.XGJobSpecificationApplicationIdentifierKey, str
        )

    @min_os_level("10.5")
    def testConstants10_5(self):
        self.assertIsInstance(XgridFoundation.XGJobSpecificationSchedulerHintsKey, str)
        self.assertIsInstance(
            XgridFoundation.XGJobSpecificationARTSpecificationsKey, str
        )
        self.assertIsInstance(XgridFoundation.XGJobSpecificationARTConditionsKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationARTDataKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationARTMinimumKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationARTMaximumKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationARTEqualKey, str)
        self.assertIsInstance(XgridFoundation.XGJobSpecificationTypeTaskListValue, str)



from PyObjCTools.TestSupport import TestCase
import XgridFoundation


class TestXGActionMonitor(TestCase):
    def testConstants(self):
        self.assertEqual(XgridFoundation.XGResourceActionNone, 0)
        self.assertEqual(XgridFoundation.XGResourceActionStop, 1)
        self.assertEqual(XgridFoundation.XGResourceActionRestart, 2)
        self.assertEqual(XgridFoundation.XGResourceActionSuspend, 3)
        self.assertEqual(XgridFoundation.XGResourceActionResume, 4)
        self.assertEqual(XgridFoundation.XGResourceActionDelete, 5)
        self.assertEqual(XgridFoundation.XGResourceActionRename, 6)
        self.assertEqual(XgridFoundation.XGResourceActionMakeDefault, 7)
        self.assertEqual(XgridFoundation.XGResourceActionSubmitJob, 8)
        self.assertEqual(XgridFoundation.XGResourceActionGetOutputStreams, 9)
        self.assertEqual(XgridFoundation.XGResourceActionGetOutputFiles, 10)
        self.assertEqual(XgridFoundation.XGResourceActionGetSpecification, 11)

        self.assertEqual(XgridFoundation.XGActionMonitorOutcomeNone, 0)
        self.assertEqual(XgridFoundation.XGActionMonitorOutcomeSuccess, 1)
        self.assertEqual(XgridFoundation.XGActionMonitorOutcomeFailure, 2)

        self.assertIsInstance(
            XgridFoundation.XGActionMonitorResultsOutputStreamsKey, str
        )
        self.assertIsInstance(XgridFoundation.XGActionMonitorResultsOutputFilesKey, str)

    def testMethods(self):
        self.assertResultIsBOOL(XgridFoundation.XGActionMonitor.actionDidSucceed)
        self.assertResultIsBOOL(XgridFoundation.XGActionMonitor.actionDidFail)



from PyObjCTools.TestSupport import TestCase
import XgridFoundation


class TestXGConnection(TestCase):
    def testConstants(self):
        self.assertEqual(XgridFoundation.XGConnectionStateClosed, 0)
        self.assertEqual(XgridFoundation.XGConnectionStateOpening, 1)
        self.assertEqual(XgridFoundation.XGConnectionStateOpen, 2)
        self.assertEqual(XgridFoundation.XGConnectionStateClosing, 3)

        self.assertIsInstance(XgridFoundation.XGConnectionKeyIsOpened, str)
        self.assertIsInstance(XgridFoundation.XGConnectionKeyIsClosed, str)
        self.assertIsInstance(XgridFoundation.XGConnectionKeyState, str)

    def testMethods(self):
        self.assertResultIsBOOL(XgridFoundation.XGConnection.isOpened)
        self.assertResultIsBOOL(XgridFoundation.XGConnection.isClosed)



# This file is generated by objective.metadata
#
# Last update: Fri May 25 17:45:37 2012
#
# flake8: noqa

import sys

import objc

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if sys.byteorder == "little":

    def littleOrBig(a, b):
        return a


else:

    def littleOrBig(a, b):
        return b


misc = {}
constants = """$XGActionMonitorResultsOutputFilesKey$XGActionMonitorResultsOutputStreamsKey$XGConnectionKeyIsClosed$XGConnectionKeyIsOpened$XGConnectionKeyState$XGControllerWillDeallocNotification$XGFileStandardErrorPath$XGFileStandardOutputPath$XGJobSpecificationARTConditionsKey$XGJobSpecificationARTDataKey$XGJobSpecificationARTEqualKey$XGJobSpecificationARTMaximumKey$XGJobSpecificationARTMinimumKey$XGJobSpecificationARTSpecificationsKey$XGJobSpecificationApplicationIdentifierKey$XGJobSpecificationArgumentTypeKey$XGJobSpecificationArgumentsKey$XGJobSpecificationCommandKey$XGJobSpecificationDependsOnJobsKey$XGJobSpecificationDependsOnTasksKey$XGJobSpecificationEnvironmentKey$XGJobSpecificationFileDataKey$XGJobSpecificationGridIdentifierKey$XGJobSpecificationInputFileMapKey$XGJobSpecificationInputFilesKey$XGJobSpecificationInputStreamKey$XGJobSpecificationIsExecutableKey$XGJobSpecificationNameKey$XGJobSpecificationNotificationEmailKey$XGJobSpecificationPathIdentifierKey$XGJobSpecificationSchedulerHintsKey$XGJobSpecificationSchedulerParametersKey$XGJobSpecificationSubmissionIdentifierKey$XGJobSpecificationTaskPrototypeIdentifierKey$XGJobSpecificationTaskPrototypesKey$XGJobSpecificationTaskSpecificationsKey$XGJobSpecificationTypeKey$XGJobSpecificationTypeTaskListValue$"""
enums = """$XGActionMonitorOutcomeFailure@2$XGActionMonitorOutcomeNone@0$XGActionMonitorOutcomeSuccess@1$XGAuthenticatorStateAuthenticated@2$XGAuthenticatorStateAuthenticating@1$XGAuthenticatorStateFailed@3$XGAuthenticatorStateUnauthenticated@0$XGConnectionStateClosed@0$XGConnectionStateClosing@3$XGConnectionStateOpen@2$XGConnectionStateOpening@1$XGFileTypeNone@0$XGFileTypeRegular@1$XGFileTypeStream@2$XGResourceActionDelete@5$XGResourceActionGetOutputFiles@10$XGResourceActionGetOutputStreams@9$XGResourceActionGetSpecification@11$XGResourceActionMakeDefault@7$XGResourceActionNone@0$XGResourceActionRename@6$XGResourceActionRestart@2$XGResourceActionResume@4$XGResourceActionStop@1$XGResourceActionSubmitJob@8$XGResourceActionSuspend@3$XGResourceStateAvailable@4$XGResourceStateCanceled@12$XGResourceStateConnecting@2$XGResourceStateFailed@13$XGResourceStateFinished@14$XGResourceStateOffline@1$XGResourceStatePending@6$XGResourceStateRunning@9$XGResourceStateStagingIn@8$XGResourceStateStagingOut@11$XGResourceStateStarting@7$XGResourceStateSuspended@10$XGResourceStateUnavailable@3$XGResourceStateUninitialized@0$XGResourceStateWorking@5$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"XGActionMonitor", b"actionDidFail", {"retval": {"type": "Z"}})
    r(b"XGActionMonitor", b"actionDidSucceed", {"retval": {"type": "Z"}})
    r(b"XGConnection", b"isClosed", {"retval": {"type": "Z"}})
    r(b"XGConnection", b"isOpened", {"retval": {"type": "Z"}})
    r(
        b"XGFileDownload",
        b"setDestination:allowOverwrite:",
        {"arguments": {3: {"type": "Z"}}},
    )
    r(b"XGGrid", b"isDefault", {"retval": {"type": "Z"}})
    r(b"XGResource", b"isUpdated", {"retval": {"type": "Z"}})
    r(b"XGResource", b"isUpdating", {"retval": {"type": "Z"}})
finally:
    objc._updatingMetadata(False)
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"authenticatorDidAuthenticate:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"authenticatorDidNotAuthenticate:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"connectionDidClose:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"connectionDidNotOpen:withError:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"connectionDidOpen:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"fileDownload:decideDestinationWithSuggestedPath:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"fileDownload:didCreateDestination:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"fileDownload:didFailWithError:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"fileDownload:didReceiveAttributes:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"fileDownload:didReceiveData:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"fileDownloadDidBegin:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"fileDownloadDidFinish:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
protocols = {
    "XGAuthenticatorDelegate": objc.informal_protocol(
        "XGAuthenticatorDelegate",
        [
            objc.selector(
                None, b"authenticatorDidNotAuthenticate:", b"v@:@", isRequired=False
            ),
            objc.selector(
                None, b"authenticatorDidAuthenticate:", b"v@:@", isRequired=False
            ),
        ],
    ),
    "XGFileDownloadDelegate": objc.informal_protocol(
        "XGFileDownloadDelegate",
        [
            objc.selector(
                None,
                b"fileDownload:decideDestinationWithSuggestedPath:",
                b"v@:@@",
                isRequired=False,
            ),
            objc.selector(
                None, b"fileDownload:didReceiveAttributes:", b"v@:@@", isRequired=False
            ),
            objc.selector(None, b"fileDownloadDidFinish:", b"v@:@", isRequired=False),
            objc.selector(
                None, b"fileDownload:didFailWithError:", b"v@:@@", isRequired=False
            ),
            objc.selector(
                None, b"fileDownload:didReceiveData:", b"v@:@@", isRequired=False
            ),
            objc.selector(None, b"fileDownloadDidBegin:", b"v@:@", isRequired=False),
            objc.selector(
                None, b"fileDownload:didCreateDestination:", b"v@:@@", isRequired=False
            ),
        ],
    ),
    "XGConnectionDelegate": objc.informal_protocol(
        "XGConnectionDelegate",
        [
            objc.selector(None, b"connectionDidOpen:", b"v@:@", isRequired=False),
            objc.selector(None, b"connectionDidClose:", b"v@:@", isRequired=False),
            objc.selector(
                None, b"connectionDidNotOpen:withError:", b"v@:@@", isRequired=False
            ),
        ],
    ),
}
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase
import XgridFoundation


class TestXGFile(TestCase):
    def testConstants(self):
        self.assertEqual(XgridFoundation.XGFileTypeNone, 0)
        self.assertEqual(XgridFoundation.XGFileTypeRegular, 1)
        self.assertEqual(XgridFoundation.XGFileTypeStream, 2)
        self.assertIsInstance(XgridFoundation.XGFileStandardOutputPath, str)
        self.assertIsInstance(XgridFoundation.XGFileStandardErrorPath, str)
